/***************************************************************

	AEUserTerminology.r

	Version:	1.3

	Copyright:	 1991-1998 by Apple Computer, Inc., All rights reserved.


 ***************************************************************/


#include <Types.r>
#include <AEUserTermTypes.r>
#include <AppleEvents.r>
#include <AEObjects.r>
#include <AERegistry.r>
#include <ASRegistry.r>

/* Macros to improve readability of terminology entries */
#define Reserved13  reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved
#define Reserved12  reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved
#define Reserved11  reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved
#define Reserved9  reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved
#define Reserved8  reserved, reserved, reserved, reserved, reserved, reserved, reserved, reserved
#define Reserved3  reserved, reserved, reserved
#define isPlural "",{"",kAESpecialClassProperties,cType,"",reserved,singleItem,notEnumerated,readOnly,Reserved8,noApostrophe,notFeminine,notMasculine,plural},{}

/* Constants defined in newer versions of OSA.r; delete when we move to Universal Headers 3.0 */
#define kOSAErrorNumber				'errn'			// in newer OSA.r
#define kOSAErrorMessage			'errs'			// in newer OSA.r
#define kOSAErrorBriefMessage		'errb'			// in newer OSA.r
#define kOSAErrorApp				'erap'			// in newer OSA.r
#define kOSAErrorPartialResult		'ptlr'			// in newer OSA.r
#define kOSAErrorOffendingObject	'erob'			// in newer OSA.r
#define kOSAErrorRange				'erng'			// in newer OSA.r
#define kOSAErrorExpectedType		'errt'			// in newer OSA.r


resource 'aeut' (0, "Standard Event Suites for English", sysheap) 
{
	0x01, 0x00, english, roman,
	{
/*

AppleScript Suite
This suite is useful only to developers of OSA languages
Do not include definitions from this suite in application terminology

*/
	"AppleScript Suite", "Standard terms for AppleScript", kASAppleScriptSuite, 1, 1,

/* Events handled by AppleScript-installed event handlers, the Applet shell, and Script Editor */
	{
	"activate", "Bring the targeted application program to the front", kAEMiscStandards, 'actv', noReply, "", replyOptional, singleItem, notEnumerated, Reserved13, noParams, "", directParamOptional, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"log", "Cause a comment to be logged", kASAppleScriptSuite, kASCommentEvent, noReply, "", replyOptional, singleItem, notEnumerated, reserved, Reserved12, typeChar, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"stop log", "Stop event logging in the script editor", kASScriptEditorSuite, kASStopLogEvent, noReply, "", replyOptional, singleItem, notEnumerated, Reserved13, noParams, "", directParamOptional, singleItem, notEnumerated, doesntChangeState, Reserved12, { }, 
	"start log", "Start event logging in the script editor", kASScriptEditorSuite, kASStartLogEvent, noReply, "", replyOptional, singleItem, notEnumerated, Reserved13, noParams, "", directParamOptional, singleItem, notEnumerated, doesntChangeState, Reserved12, { }, 
	"idle", "Sent to a script application when it is idle", kAEMiscStandards, 'idle', typeInteger, "the number of seconds to wait for next idle event", replyRequired, singleItem, notEnumerated, Reserved13, noParams, "", directParamOptional, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"launch", "Start an application for scripting", kASAppleScriptSuite, 'noop', typeNull, "", replyOptional, singleItem, notEnumerated, Reserved13, noParams, "", directParamOptional, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"tell", "Record or log a tell statement", kASAppleScriptSuite, kASMagicTellEvent, typeNull, "", replyOptional, singleItem, notEnumerated, Reserved13, noParams, "", directParamRequired, singleItem, notEnumerated, doesntChangeState, Reserved12, { }, 
	"end tell", "Record or log an end tell statement", kASAppleScriptSuite, kASMagicEndTellEvent, typeNull, "", replyOptional, singleItem, notEnumerated, Reserved13, noParams, "", directParamOptional, singleItem, notEnumerated, doesntChangeState, Reserved12, { }, 
	"error", "Raise an error", kASAppleScriptSuite, kASErrorEventCode, typeNull, "", replyOptional, singleItem, notEnumerated, Reserved13, typeWildCard, "", directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
		{
		"number", keyErrorNumber, typeShortInteger, "an error number", optional, singleItem, notEnumerated, Reserved13, 
		"partial result", kOSAErrorPartialResult, 
		typeAEList, "any partial result occurring before the error", optional, singleItem, notEnumerated, Reserved13, 
		"from", kOSAErrorOffendingObject, typeWildCard, "the object that caused the error", optional, singleItem, notEnumerated, Reserved13, 
		"to", kOSAErrorExpectedType, 
		typeWildCard, "the desired class for a failed coercion", optional, singleItem, notEnumerated, Reserved13, 
		}, 
	"Callsubroutine", "A subroutine call", kASAppleScriptSuite, kASPrepositionalSubroutine, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeWildCard, "", directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
		{
		"at", keyASPrepositionAt, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"from", keyASPrepositionFrom, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"for", keyASPrepositionFor, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"to", keyASPrepositionTo, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"thru", keyASPrepositionThru, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"through", keyASPrepositionThrough, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"by", keyASPrepositionBy, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"on", keyASPrepositionOn, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"into", keyASPrepositionInto, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"onto", keyASPrepositionOnto, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"between", keyASPrepositionBetween, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"against", keyASPrepositionAgainst, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"out of", keyASPrepositionOutOf, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"instead of", keyASPrepositionInsteadOf, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"aside from", keyASPrepositionAsideFrom, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"around", keyASPrepositionAround, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"beside", keyASPrepositionBeside, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"beneath", keyASPrepositionBeneath, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"under", keyASPrepositionUnder, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"over", keyASPrepositionOver, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"above", keyASPrepositionAbove, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"below", keyASPrepositionBelow, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"apart from", keyASPrepositionApartFrom, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"about", keyASPrepositionAbout, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"since", keyASPrepositionSince, typeWildCard, "a preposition", optional, singleItem, notEnumerated, Reserved13, 
		"given", keyASPrepositionGiven, typeWildCard, "parameter:value pairs, comma-separated", optional, singleItem, notEnumerated, Reserved13, 
		"with", keyASPrepositionWith, typeType, "formal parameter set to true if matching actual parameter is provided", optional, singleItem, notEnumerated, Reserved13, 
		"without", keyASPrepositionWithout, typeType, "formal parameter set to false if matching actual parmeter is provided", optional, singleItem, notEnumerated, Reserved13, 
		},

/*  Events: AppleScript Operators */
	"=", "Equality", kASAppleScriptSuite, kASEqual, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"", "Inequality", kASAppleScriptSuite, kASNotEqual, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"+", "Addition", kASAppleScriptSuite, kASAdd, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"-", "Subtraction", kASAppleScriptSuite, kASSubtract, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"*", "Multiplication", kASAppleScriptSuite, kASMultiply, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"", "Division", kASAppleScriptSuite, kASDivide, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"div", "Quotient", kASAppleScriptSuite, kASQuotient, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"mod", "Remainder", kASAppleScriptSuite, kASRemainder, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"^", "Exponentiation", kASAppleScriptSuite, kASPower, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	">", "Greater than", kASAppleScriptSuite, kASGreaterThan, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"", "Greater than or equal to", kASAppleScriptSuite, kASGreaterThanOrEqual, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"<", "Less than", kASAppleScriptSuite, kASLessThan, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"", "Less than or equal to", kASAppleScriptSuite, kASLessThanOrEqual, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"&", "Concatenation", kASAppleScriptSuite, kASConcatenate, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"starts with", "Starts with", kASAppleScriptSuite, kASStartsWith, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"ends with", "Ends with", kASAppleScriptSuite, kASEndsWith, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"contains", "Containment", kASAppleScriptSuite, kASContains, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"and", "Logical conjunction", kASAppleScriptSuite, kAEAND, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"or", "Logical disjunction", kASAppleScriptSuite, kAEOR, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"as", "Coercion", kASAppleScriptSuite, 'coer', typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"not", "Logical negation", kASAppleScriptSuite, kAENOT, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"negate", "Numeric negation", kASAppleScriptSuite, kASNegate, typeWildCard, "", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	},

/* Classes: user-visible */
	{
	"boolean", cBoolean, "A true or false value", { }, { }, 
	"booleans", cBoolean, isPlural, 
	"integer", cLongInteger, "An integral number", { }, { }, 
	"integers", cLongInteger, isPlural, 
	"real", cReal, "A real number", { }, { }, 
	"reals", cReal, isPlural, 
	"number", cNumber, "an integer or real number", { }, { }, 
	"numbers", cNumber, isPlural, 
	"list", cList, "An ordered collection of items",
		{
		"length", pLength, typeLongInteger, "the length of a list", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"reverse", pReverse, typeAEList, "the items of the list in reverse order", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"rest", pRest, typeAEList, "all items of the list excluding first", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular,
		}, { }, 
	"lists", cList, isPlural, 
	"linked list", cLinkedList, "An ordered collection of items",
		{
		"length", pLength, typeLongInteger, "the length of a list", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		}, { }, 
	"linked lists", cLinkedList, isPlural,
	"vector", cVector, "An ordered collection of items",
		{
		"length", pLength, typeLongInteger, "the length of a list", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		}, { }, 
	"vectors", cVector, isPlural,
	"record", cRecord, "A set of labeled items", { }, { }, 
	"records", cRecord, isPlural,
	"item", cObject, "An item of any type",
		{
		"id", formUniqueID, cLongInteger, "the unique ID number of this object", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		}, { }, 
	"items", cObject, isPlural,
	"script", cScript, "An AppleScript script",
		{
		"name", pName, typeChar, "the name of the script", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"parent", pASParent, cScript, "its parent, i.e. the script that will handle events that this script doesnt", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		}, { },
	"scripts", cScript, isPlural,
	"list or record", cListOrRecord, "a list or record", { }, { },
	"list or string", cListOrString, "a list or string", { }, { },
	"number or string", cNumberOrString, "a number or string", { }, { },
	"alias or string", cAliasOrString, "an alias or string", { }, { }, 
	"list, record or text", cListRecordOrString, "a list, record or text", { }, { },
	"number or date", cNumberOrDateTime, "a number or date", { }, { },
	"number, date or text", cNumberDateTimeOrString, "a number, date or text", { }, { },

/* Classes:  syntax element names for chevron syntax */
	"class", cClassIdentifier, "the type of a value",
		{
		"<Inheritance>", pInherits, typeType, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular
		}, { }, 
	"classes", cClassIdentifier, isPlural,
	"event", cEventIdentifier, "an AppleEvents event", { }, { }, 
	"events", cEventIdentifier, isPlural,
	"property", cProperty, "an AppleEvents property", { }, { }, 
	"properties", cProperty, isPlural,
	"constant", cConstant, "A constant value", { }, { }, 
	"constants", cConstant, isPlural,
	"preposition", cPreposition, "an AppleEvents preposition", { }, { }, 
	"prepositions", cPreposition, isPlural,
	"reference form", cKeyForm, "an AppleEvents key form", { }, { }, 
	"reference forms", cKeyForm, isPlural,
	"handler", cHandler, "an AppleScript event or subroutine handler", { }, { }, 
	"handlers", cHandler, isPlural,
	"data", cRawData, "an AppleScript raw data object", { }, { },

/* Classes: string and text*/
	"text", cText, "text with language and style information", { }, { },
	"international text", typeIntlText, isPlural, 
	"international text", typeIntlText, "text that begins with a writing code", { }, { },
	"string", typeChar, "text in 8-bit Macintosh Roman format", { }, { }, 
	"strings", typeChar, isPlural,
	"styled text", typeStyledText, isPlural, 
	"styled text", typeStyledText, "text with font, size, and style information", { }, { },
	"styled Clipboard text", 'styl', isPlural, 
	"styled Clipboard text", 'styl', "clipboard text with font, size, and style information", { }, { },
	"Unicode text", typeUnicodeText, isPlural, 
	"Unicode text", typeUnicodeText, "text in the Unicode format (cannot be viewed without conversion)", { }, { }, 
	"styled Unicode text", typeStyledUnicodeText, isPlural, 
	"styled Unicode text", typeStyledUnicodeText, "styled text in the Unicode format", { }, { },
	"encoded string", typeEncodedString, "text encoded using the Text Encoding Converter", { }, { }, 
	"encoded strings", typeEncodedString, isPlural,
	"C string", typeCString, "text followed by a null", { }, { }, 
	"C strings", typeCString, isPlural,
	"Pascal string", typePString, "text up to 255 characters preceded by a length byte", { }, { },	
	"Pascal strings", typePString, isPlural,	
	"character", cChar, "an individual text character", { }, { }, 
	"characters", cChar, isPlural, 
	"text item", cItem, "text between delimiters", { }, { }, 
	"text items", cItem, isPlural,
	"writing code", pScriptTag, "codes that identify the language and script system", { }, { },
	"writing code info", cWritingCodeInfo, "script code and language code of text run",
		{
		"script code", pScriptCode, cShortInteger, "the script code for the text", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"language code", pLangCode, cShortInteger, "the language code for the text", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		}, { },
	"writing code infos", cWritingCodeInfo, isPlural,

/* Classes: Special Value Classes */
	"", cUndefined, "the undefined value", { },{ },
	"missing value", cMissingValue, "unavailable value, such as properties missing from heterogeneous classes in a Whose clause", { }, { }, 
	"missing values", cMissingValue, isPlural, 
	"reference", cReference, "an AppleScript reference", { }, { }, 
	"references", cReference, isPlural,
	"anything", typeWildCard, "any class or reference", { }, { },
	"type class", cType, "the name of a particular class (or any four-character code)", { }, { },

/* Classes: Systemwide values */
	"RGB color", cRGBColor, "Three integers specifying red, green, blue color values", { }, { }, 
	"RGB colors", cRGBColor, isPlural,
	"picture", cPICT, "A QuickDraw picture object", { }, { }, 
	"pictures", cPICT, isPlural,
	"sound", typeSound, "a sound object on the clipboard", { }, { }, 
	"sounds", typeSound, isPlural, 
	"version", cVersion, "a version value", { }, { },
	"file specification", typeFSS, "a file specification as used by the operating system", { }, { }, 
	"file specifications", typeFSS, isPlural,
	"alias", typeAlias, "a file on a disk or server.  The file must exist when you check the syntax of your script.", { }, { }, 
	"aliases", typeAlias, isPlural,
	"machine", 'mach', "a computer", { }, { }, 
	"machines", 'mach', isPlural, 
	"zone", 'zone', "an AppleTalk zone", { }, { }, 
	"zones", 'zone', isPlural,
	"keystroke", cKeystroke, "a press of a key combination on a Macintosh keyboard",
		{
		"key", pKeystrokeKey, cChar, "the character for the key was pressed (ignoring modifiers)", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"modifiers", pModifiers, eModifiers, "the modifier keys pressed in combination", reserved, listOfItems, enumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"key kind", pKeyKind, eKeyKind, "the kind of key that was pressed", reserved, singleItem, enumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular
		}, { }, 
	"keystrokes", cKeystroke, isPlural, 
	"seconds", cSeconds, "more than one second", { }, { },
	"date", cLongDateTime, "Absolute date and time values",
		{
		"weekday", pASWeekday, cWeekday, "the day of a week of a date", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"month", pASMonth, cMonth, "the month of a date", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"day", pASDay, typeLongInteger, "the day of the month of a date", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"year", pASYear, typeLongInteger, "the year of a date", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"time", pASTime, typeLongInteger, "the time since midnight of a date", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"date string", pASDateString, typeChar, "the date portion of a date-time value as text", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"time string", pASTimeString, typeChar, "the time portion of a date-time value as text", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		}, { },
	"dates", cLongDateTime, isPlural, 

/* Classes: Month and Day Names*/
	"month", cMonth, "a month", { }, { }, 
	"months", cMonth, isPlural, 
	"January", cJanuary, "the month of January", { }, { }, 
	"February", cFebruary, "the month of February", { }, { }, 
	"March", cMarch, "the month of March", { }, { }, 
	"April", cApril, "the month of April", { }, { }, 
	"May", cMay, "the month of May", { }, { }, 
	"June", cJune, "the month of June", { }, { }, 
	"July", cJuly, "the month of July", { }, { }, 
	"August", cAugust, "the month of August", { }, { }, 
	"September", cSeptember, "the month of September", { }, { }, 
	"October", cOctober, "the month of October", { }, { }, 
	"November", cNovember, "the month of November", { }, { }, 
	"December", cDecember, "the month of December", { }, { },
	"weekday", cWeekday, "a weekday", { }, { }, 
	"weekdays", cWeekday, isPlural, 
	"Sunday", cSunday, "Sunday", { }, { }, 
	"Monday", cMonday, "Monday", { }, { }, 
	"Tuesday", cTuesday, "Tuesday", { }, { }, 
	"Wednesday", cWednesday, "Wednesday", { }, { }, 
	"Thursday", cThursday, "Thursday", { }, { }, 
	"Friday", cFriday, "Friday", { }, { }, 
	"Saturday", cSaturday, "Saturday", { }, { },

/* Classes: Unit coercion base types */
	"metres", typeMeters, "a distance measurement in SI meters", { }, { }, 
	"meters", typeMeters, "a distance measurement in SI meters", { }, { }, 
	"inches", typeInches, "a distance measurement in Imperial inches", { }, { }, 
	"feet", typeFeet, "a distance measurement in Imperial feet", { }, { }, 
	"yards", typeYards, "a distance measurement in Imperial yards", { }, { }, 
	"miles", typeMiles, "a distance measurement in Imperial miles", { }, { }, 
	"kilometres", typeKilometers, "a distance measurement in SI kilometers", { }, { }, 
	"kilometers", typeKilometers, "a distance measurement in SI kilometers", { }, { }, 
	"centimetres", typeCentimeters, "a distance measurement in SI centimeters", { }, { }, 
	"centimeters", typeCentimeters, "a distance measurement in SI centimeters", { }, { }, 
	"square metres", typeSquareMeters, "an area measurement in SI square meters", { }, { }, 
	"square meters", typeSquareMeters, "an area measurement in SI square meters", { }, { }, 
	"square feet", typeSquareFeet, "an area measurement in Imperial square feet", { }, { }, 
	"square yards", typeSquareYards, "an area measurement in Imperial square yards", { }, { }, 
	"square miles", typeSquareMiles, "an area measurement in Imperial square miles", { }, { }, 
	"square kilometres", typeSquareKilometers, "an area measurement in SI square kilometers", { }, { }, 
	"square kilometers", typeSquareKilometers, "an area measurement in SI square kilometers", { }, { }, 
	"litres", typeLiters, "a volume measurement in SI liters", { }, { }, 
	"liters", typeLiters, "a volume measurement in SI liters", { }, { }, 
	"gallons", typeGallons, "a volume measurement in Imperial gallons", { }, { }, 
	"quarts", typeQuarts, "a volume measurement in Imperial quarts", { }, { }, 
	"cubic metres", typeCubicMeters, "a volume measurement in SI cubic meters", { }, { }, 
	"cubic meters", typeCubicMeters, "a volume measurement in SI cubic meters", { }, { }, 
	"cubic centimetres", typeCubicCentimeter, "a volume measurement in SI cubic centimeters", { }, { }, 
	"cubic centimeters", typeCubicCentimeter, "a volume measurement in SI cubic centimeters", { }, { }, 
	"cubic feet", typeCubicFeet, "a volume measurement in Imperial cubic feet", { }, { }, 
	"cubic inches", typeCubicInches, "a volume measurement in Imperial cubic inches", { }, { }, 
	"cubic yards", typeCubicYards, "a distance measurement in Imperial cubic yards", { }, { }, 
	"kilograms", typeKilograms, "a mass measurement in SI kilograms", { }, { }, 
	"grams", typeGrams, "a mass measurement in SI meters", { }, { }, 
	"ounces", typeOunces, "a weight measurement in SI meters", { }, { }, 
	"pounds", typePounds, "a weight measurement in SI meters", { }, { }, 
	"degrees Celsius", typeDegreesC, "a temperature measurement in SI degrees Celsius", { }, { }, 
	"degrees Fahrenheit", typeDegreesF, "a temperature measurement in degrees Fahrenheit", { }, { },

/* Classes: other */
	"upper case", kAECase, "Text with lower case converted to upper case", { }, { },
	"app", cApplication, "Short name for application", { }, { }, 
	"application", cApplication, "specifies global properties of AppleScript",
		{
		"result", pASResult, typeWildCard, "the last result of evaluation", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"space", pASSpace, cChar, "a space character", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"return", pASReturn, cChar, "a return character", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"tab", pASTab, cChar, "a tab character", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"minutes", pASMinutes, typeInteger, "the number of seconds in a minute", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"hours", pASHours, typeInteger, "the number of seconds in an hour", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"days", pASDays, typeInteger, "the number of seconds in a day", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"weeks", pASWeeks, typeInteger, "the number of seconds in a week", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"pi", pASPi, cReal, "the constant pi", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"print length", pASPrintLength, typeLongInteger, "the maximum length to print", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"print depth", pASPrintDepth, typeLongInteger, "the maximum depth to print", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"text item delimiters", pTextItemDelimiters, typeAEList, "the text item delimiters of a string", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"AppleScript", pASTopLevelScript, cScript, "the top-level script object", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		}, { },
	"applications", cApplication, isPlural, 
	},

	{ },

/* Enumerations */
	{
	enumConsiderations,
		{
		"case", kAECase, "case", 
		"diacriticals", kAEDiacritic, "diacriticals", 
		"white space", kAEWhiteSpace, "white space", 
		"hyphens", kAEHyphens, "hyphens", 
		"expansion", kAEExpansion, "expansion", 
		"punctuation", kAEPunctuation, "punctuation", 
		"application responses", kASConsiderReplies, "remote event replies", 
		}, 
	enumBooleanValues,
		{
		"true", kAETrue , "the true boolean value", 
		"false", kAEFalse , "the false boolean value", 
		}, 
	enumMiscValues,
		{
		"current application", kASCurrentApplication, "the current application", 
		},
	eModifiers, { 
		"option down",		eOptionDown, "", 
		"command down",		eCommandDown, "", 
		"control down",		eControlDown, "", 
		"shift down",		eShiftDown, "", 
		"caps lock down",	eCapsLockDown, ""
		}, 
	eKeyKind,
		{
		"escape key",			eEscapeKey, "", 
		"delete key",			eDeleteKey, "", 
		"tab key",				eTabKey, "", 
		"return key",			eReturnKey, "", 
		"clear key",			eClearKey, "", 
		"enter key",			eEnterKey, "", 
		"up arrow key",			eUpArrowKey, "", 
		"down arrow key",		eDownArrowKey, "", 
		"left arrow key",		eLeftArrowKey, "", 
		"right arrow key",		eRightArrowKey, "", 
		"help key",				eHelpKey, "", 
		"home key",				eHomeKey, "", 
		"page up key",			ePageUpKey, "", 
		"page down key",		ePageDownKey, "", 
		"forward del key",		eForwardDelKey, "", 
		"end key",				eEndKey, "", 
		"F1 key",				eF1Key, "", 
		"F2 key",				eF2Key, "", 
		"F3 key",				eF3Key, "", 
		"F4 key",				eF4Key, "", 
		"F5 key",				eF5Key, "", 
		"F6 key",				eF6Key, "", 
		"F7 key",				eF7Key, "", 
		"F8 key",				eF8Key, "", 
		"F9 key",				eF9Key, "", 
		"F10 key",				eF10Key, "", 
		"F11 key",				eF11Key, "", 
		"F12 key",				eF12Key, "", 
		"F13 key",				eF13Key, "", 
		"F14 key",				eF14Key, "", 
		"F15 key",				eF15Key, ""
		},
	}, 

/*

Required Suite
Obsoleted in AppleScript 1.3 and later
Contents moved to Standard Suite

*/
	"Required Suite", "Every application supports open, print, run, and quit", kAERequiredSuite, 1, 1,
	{ },
	{ },
	{ },
	{ },

/*

Standard Suite
If your application supports the Standard Suite in its entirety, simply include an empty suite with type kAECoreSuite.
If you only support a subset of the Standard Suite, copy the appropriate events and/or classes from this suite
and include them in your application.

*/

	"Standard Suite", "Common terms for most applications", kAECoreSuite, 1, 1,

/* Standard Suite Events */
	{
	"open", "Open the specified object(s)", kCoreEventClass, kAEOpen, noReply, "", replyOptional, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "list of objects to open", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"run", "Run an application.  Most applications will open an empty, untitled window.", kCoreEventClass, kAEOpenApplication, noReply, "", replyOptional, singleItem, notEnumerated, Reserved13, noParams, "no direct parameter required", directParamOptional, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"reopen", "Reactivate a running application.  Some applications will open a new untitled window if no window is open.", kCoreEventClass, 'rapp', noReply, "", replyOptional, singleItem, notEnumerated, Reserved13, noParams, "no direct parameter required", directParamOptional, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"print", "Print the specified object(s)", kCoreEventClass, kAEPrint, noReply, "", replyOptional, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "list of objects to print", directParamRequired, singleItem, notEnumerated, doesntChangeState, Reserved12, { }, 
	"quit", "Quit an application", kCoreEventClass, kAEQuitApplication, noReply, "", replyOptional, singleItem, notEnumerated, Reserved13, noParams, "", directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
		{
		"saving", keyAESaveOptions, enumSaveOptions, "specifies whether to save currently open documents", optional, singleItem, enumerated, Reserved13, 
		}, 
	"close", "Close an object", kAECoreSuite, kAEClose, noReply, "", replyOptional, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "the object to close", directParamRequired, singleItem, notEnumerated, changesState, Reserved12,
		{
		"saving", keyAESaveOptions, enumSaveOptions, "specifies whether changes should be saved before closing", optional, singleItem, enumerated, Reserved13, 
		"saving in", keyAEFile, typeAlias, "the file in which to save the object", optional, singleItem, notEnumerated, Reserved13, 
		}, 
	"count", "Return the number of elements of an object", kAECoreSuite, kAECountElements, typeLongInteger, "the number of elements", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "the object whose elements are to be counted", directParamRequired, singleItem, notEnumerated, doesntChangeState, Reserved12,
		{
		"each", keyAEObjectClass, typeType, "if specified, restricts counting to objects of this class", optional, singleItem, notEnumerated, Reserved13, 
		}, 
	"delete", "Delete an object from its container. Note this does not work on script variables, only on elements of application classes.", kAECoreSuite, kAEDelete, noReply, "", replyOptional, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "the element to delete", directParamRequired, singleItem, notEnumerated, changesState, Reserved12, { }, 
	"duplicate", "Duplicate one or more objects", kAECoreSuite, kAEClone, typeObjectSpecifier, "to the duplicated object(s)", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "the object(s) to duplicate", directParamRequired, singleItem, notEnumerated, changesState, Reserved12,
		{
		"to", keyAEInsertHere, typeInsertionLoc, "the new location for the object(s)", optional, singleItem, notEnumerated, Reserved13, 
		"with properties", keyAEPropData, typeAERecord, "the initial values for properties of the new object that are to be different from the original", optional, singleItem, notEnumerated, Reserved13
		}, 
	"exists", "Verify if an object exists", kAECoreSuite, kAEDoObjectsExist, typeBoolean, "true if it exists, false if not", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "the object in question", directParamRequired, singleItem, notEnumerated, doesntChangeState, Reserved12, { }, 
	"make", "Make a new element", kAECoreSuite, kAECreateElement, typeObjectSpecifier, "to the new object(s)", replyRequired, singleItem, notEnumerated, Reserved13, noParams, "", directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
		{
		"new", keyAEObjectClass, typeType, "the class of the new element", required, singleItem, notEnumerated, Reserved13, 
		"at", keyAEInsertHere, typeInsertionLoc, "the location at which to insert the element", optional, singleItem, notEnumerated, Reserved13, 
		"with data", keyAEData, typeWildCard, "the initial data for the element", optional, singleItem, notEnumerated, Reserved13, 
		"with properties", keyAEPropData, typeAERecord, "the initial values for the properties of the element", optional, singleItem, notEnumerated, Reserved13
		}, 
	"move", "Move object(s) to a new location", kAECoreSuite, kAEMove, typeObjectSpecifier, "to the object(s) after they have been moved", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "the object(s) to move", directParamRequired, singleItem, notEnumerated, changesState, Reserved12,
		{
		"to", keyAEInsertHere, typeInsertionLoc, "the new location for the object(s)", required, singleItem, notEnumerated, Reserved13, 
		}, 
	"save", "Save an object", kAECoreSuite, kAESave, noReply, "", replyOptional, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "the object to save, usually a document or window", directParamRequired, singleItem, notEnumerated, changesState, Reserved12,
		{
		"in", keyAEFile, typeAlias, "the file in which to save the object", optional, singleItem, notEnumerated, Reserved13, 
		"as", keyAEFileType, typeType, "the file type of the document in which to save the data", optional, singleItem, notEnumerated, Reserved13
		}, 
	"select", "Make a selection", kAEMiscStandards, kAESelect, noReply, "", replyOptional, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "the object to select", directParamRequired, singleItem, notEnumerated, changesState, reserved12, { }, 
	"data size", "(optional) Return the size in bytes of an object", kAECoreSuite, kAEGetDataSize, typeLongInteger, "the size of the object in bytes", replyRequired, singleItem, notEnumerated, Reserved13, typeObjectSpecifier, "the object whose data size is to be returned", directParamRequired, singleItem, notEnumerated, doesntChangeState, Reserved12,
		{
		"as", keyAERequestedType, typeType, "the data type for which the size is calculated", optional, singleItem, notEnumerated, Reserved13, 
		}, 
	"suite info", "(optional) Get information about event suite(s)", kAECoreSuite, kAEGetSuiteInfo, typeSuiteInfo, "a record containing the suites and their versions", replyRequired, listOfItems, notEnumerated, Reserved13, typeType, "the suite for which to return information", directParamRequired, singleItem, notEnumerated, doesntChangeState, Reserved12,
		{
		"in", keyAEWritingCode, typeIntlWritingCode, "the human language and script system in which to return information", optional, singleItem, notEnumerated, Reserved13, 
		}, 
	"event info", "(optional) Get information about the Apple events in a suite", kAECoreSuite, kAEGetEventInfo, typeEventInfo, "a record containing the events and their parameters", replyRequired, listOfItems, notEnumerated, Reserved13, typeType, "the event class of the Apple events for which to return information", directParamRequired, singleItem, notEnumerated, doesntChangeState, Reserved12,
		{
		"in", keyAEWritingCode, typeIntlWritingCode, "the human language and script system in which to return information", optional, singleItem, notEnumerated, Reserved13, 
		}, 
	"class info", "(optional) Get information about an object class", kAECoreSuite, kAEGetClassInfo, typeClassInfo, "a record containing the objects properties and elements", replyRequired, singleItem, notEnumerated, Reserved13, typeType, "the object class about which information is requested", directParamOptional, singleItem, notEnumerated, doesntChangeState, Reserved12,
		{
		"in", keyAEWritingCode, typeIntlWritingCode, "the human language and script system in which to return information", optional, singleItem, notEnumerated, Reserved13, 
		}, 
	},

/* Standard Suite Classes */
	{
	"application", cApplication, "An application program", 
		{
		"name", pName, cIntlText, "the name of the application", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"frontmost", pIsFrontProcess, cBoolean, "Is this the frontmost application?", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"selection", pSelection, cSelection, "the selection visible to the user.  Use the select command to set a new selection; use contents of selection to get or change information in the document.", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"clipboard", pClipboard, typeWildCard, "the contents of the clipboard for this application", reserved, listOfItems, notEnumerated, readWrite, Reserved11, singular, 
		"version", pVersion, cVersion, "the version of the application", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular,
		}, { },
	"applications", cApplication, isPlural,
	"document", cDocument, "A document of a scriptable application",
		{
		"modified", pIsModified, cBoolean, "Has the document been modified since the last save?", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		}, { },
	"documents", cDocument, isPlural,
	"file", cFile, "a file on a disk or server (or a file yet to be created)",
		{
		"stationery", pIsStationeryPad, cBoolean, "Is the file a stationery file?", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular,
		}, { },
	"files", cFile, isPlural,
	"alias", typeAlias, "a file on a disk or server.  The file must exist when you check the syntax of your script.", { }, { }, 
	"aliases", typeAlias, isPlural,
	"selection-object", cSelection, "A way to refer to the state of the current of the selection.  Use the select command to make a new selection.",
		{
		"contents", pContents, typeWildCard, "the information currently selected.  Use contents of selection to get or change information in a document.", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		}, { },
	"window", cWindow, "A window",
		{
		"bounds", pBounds, cQDRectangle, "the boundary rectangle for the window", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"closeable", pHasCloseBox, cBoolean, "Does the window have a close box?", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"titled", pHasTitleBar, cBoolean, "Does the window have a title bar?", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"index", pIndex, cLongInteger, "the number of the window", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"floating", pIsFloating, cBoolean, "Does the window float?", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"modal", pIsModal, cBoolean, "Is the window modal?", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"resizable", pIsResizable, cBoolean, "Is the window resizable?", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"zoomable", pIsZoomable, cBoolean, "Is the window zoomable?", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"zoomed", pIsZoomed, cBoolean, "Is the window zoomed?", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"visible", pVisible, cBoolean, "Is the window visible?", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		}, { },
	"windows", cWindow, isPlural,
	"insertion point", cInsertionPoint, "An insertion location between two objects", { }, { },
	"insertion points", cInsertionPoint, isPlural,
	},

/* Comparison Operators */
	{
	"starts with", kAEBeginsWith, "Starts with", 
	"contains", kAEContains, "Contains", 
	"ends with", kAEEndsWith, "Ends with", 
	"=", kAEEquals, "Equal", 
	">", kAEGreaterThan, "Greater than", 
	"", kAEGreaterThanEquals, "Greater than or equal to", 
	"<", kAELessThan, "Less than", 
	"", kAELessThanEquals, "Less than or equal to", 
	},

/* Enumerations */
	{
	enumSaveOptions,
		{
		"yes", kAEYes, "Save objects now", 
		"no", kAENo , "Do not save objects", 
		"ask", kAEAsk , "Ask the user whether to save", 
		}, 	
	enumKeyForm,
		{
		"index", formAbsolutePosition, "keyform designating indexed access", 
		"named", formName, "keyform designating named access", 
		"id", formUniqueID, "keyform designating access by unique identifier"
		}, 
	enumStyle,
		{
		"plain", kAEPlain, "Plain", 
		"bold", kAEBold, "Bold", 
		"italic", kAEItalic, "Italic", 
		"outline", kAEOutline, "Outline", 
		"shadow", kAEShadow, "Shadow", 
		"underline", kAEUnderline, "Underline", 
		"superscript", kAESuperscript, "Superscript", 
		"subscript", kAESubscript, "Subscript", 
		"strikethrough", kAEStrikethrough, "Strikethrough", 
		"small caps", kAESmallCaps, "Small caps", 
		"all caps", kAEAllCaps , "All capital letters", 
		"all lowercase", kAELowercase, "Lowercase", 
		"condensed", kAECondensed, "Condensed", 
		"expanded", kAEExpanded, "Expanded", 
		"hidden", kAEHidden, "Hidden", 
		}, 
	}, 
	
/*

Text Suite

*/
		
	"Text Suite", "A set of basic classes for text processing", kAETextSuite, 1, 1, 

/* Events */		
	{ },

/* Classes */
	{
	"character", cChar, "A character",
		{
		"<inheritance>", pInherits, cText, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		}, { },
	"line", cLine, "A line of text",
		{
		"<inheritance>", pInherits, cText, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"justification", pJustification, enumJustification, "the justification of the text", reserved, singleItem, enumerated, readWrite, Reserved11, singular, 
		}, { },
	"lines", cLine, isPlural,
	"paragraph", cParagraph, "A paragraph",
		{
		"<inheritance>", pInherits, cText, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		}, { },
	"paragraphs", cParagraph, isPlural,
	"text", cText, "Text",
		{
		"", kAESpecialClassProperties, cType, "", reserved, singleItem, notEnumerated, readOnly, Reserved11, plural,
		"color", pColor, cRGBColor, "the color of the first character", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular,
		"font", pFont, cText, "the name of the font of the first character", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular,
		"size", pPointSize, cFixed, "the size in points of the first character", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular,
		"writing code", pScriptTag, cIntlWritingCode, "the script system and language", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular,
		"style", pTextStyles, cTextStyles, "the text style of the first character of the first character", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular,
		"uniform styles", pUniformStyles, cTextStyles, "the text styles that are uniform throughout the text", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular,
		},
		{
		cChar, { formAbsolutePosition }, 
		cLine, { formAbsolutePosition }, 
		cParagraph, { formAbsolutePosition }, 
		cText, { formAbsolutePosition }, 
		cWord, { formAbsolutePosition },
		}, 
	"text flow", cTextFlow, "A contiguous block of text.  Page layout applications call this a story.",
		{
		"<inheritance>", pInherits, cText, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"name", pName, cIntlText, "the name", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		}, { },
	"text flows", cTextFlow, isPlural,
	"text style info", cTextStyles, "On and Off styles of text run",
		{
		"on styles", keyAEOnStyles, enumStyle, "the styles that are on for the text", reserved, listOfItems, enumerated, readOnly, Reserved11, singular, 
		"off styles", keyAEOffStyles, enumStyle, "the styles that are off for the text", reserved, listOfItems, enumerated, readOnly, Reserved11, singular, 
		}, { },
	"text style infos", cTextStyles, isPlural,
	"word", cWord, "A word",
		{
		"<inheritance>", pInherits, cText, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		}, { },
	"words", cWord, isPlural,
	}, 
	
	{ },

/* Enumerations */
	{
	enumJustification,
		{
		"left", kAELeftJustified, "Align with left margin", 
		"right", kAERightJustified, "Align with right margin", 
		"center", kAECentered, "Align with center", 
		"full", kAEFullyJustified, "Align with both left and right margins"
		}, 
	enumStyle,
		{
		"plain", kAEPlain, "Plain", 
		"bold", kAEBold, "Bold", 
		"italic", kAEItalic, "Italic", 
		"outline", kAEOutline, "Outline", 
		"shadow", kAEShadow, "Shadow", 
		"underline", kAEUnderline, "Underline", 
		"superscript", kAESuperscript, "Superscript", 
		"subscript", kAESubscript, "Subscript", 
		"strikethrough", kAEStrikethrough, "Strikethrough", 
		"small caps", kAESmallCaps, "Small caps", 
		"all caps", kAEAllCaps , "All capital letters", 
		"all lowercase", kAELowercase, "Lowercase", 
		"condensed", kAECondensed, "Condensed", 
		"expanded", kAEExpanded, "Expanded", 
		"hidden", kAEHidden, "Hidden", 
		}, 
	}, 

/*

QuickDraw Graphic Suite

*/

	"QuickDraw Graphics Suite", "A set of basic classes for graphics", kAEQuickDrawSuite, 1, 1,

/* Events */
	{ },

/* Classes */
	{
	"arc", cArc, "An arc",
		{
		"arc angle", pArcAngle, cFixed, "the angle of the arc in degrees", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"bounds", pBounds, cQDRectangle, "the smallest rectangle that contains the entire arc", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"definition rect", pDefinitionRect, cQDRectangle, "the rectangle that contains the circle or oval used to define the arc", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"fill color", pFillColor, cRGBColor, "the fill color", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"fill pattern", pFillPattern, cPixelMap, "the fill pattern", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"pen color", pPenColor, cRGBColor, "the pen color", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"pen pattern", pPenPattern, cPixelMap, "the pen pattern", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"pen width", pPenWidth, cShortInteger, "the pen width", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"start angle", pStartAngle, cFixed, "the angle that defines the start of the arc, in degrees", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"transfer mode", pTransferMode, enumTransferMode, "the transfer mode", reserved, singleItem, enumerated, readWrite, Reserved11, singular, 
		}, { },
	"arcs", cArc, isPlural,
	"drawing area", cDrawingArea, "Container for graphics and supporting information",
		{
		"background color", pBackgroundColor, cRGBColor, "the color used to fill in unoccupied areas", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"background pattern", pBackgroundPattern, cPixelMap, "the pattern used to fill in unoccupied areas", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"color table", pColorTable, cColorTable, "the color table", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"ordering", pGraphicObjects, typeObjectSpecifier, "the ordered list of graphic objects in the drawing area", reserved, listOfItems, notEnumerated, readWrite, Reserved11, singular, 
		"name", pName, cIntlText, "the name", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"default location", pNewElementLoc, cQDPoint, "the default location of each new graphic object", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"pixel depth", pPixelDepth, cShortInteger, "the number of bits per pixel", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"writing code", pScriptTag, cIntlWritingCode, "the script system and language of text objects in the drawing area", reserved, singleItem, notEnumerated, readOnly, Reserved11, singular, 
		"text color", pTextColor, cRGBColor, "the default color for text objects", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"default font", pTextFont, cIntlText, "the name of the default font for text objects", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"default size", pTextPointSize, cFixed, "the default size for text objects", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"style", pTextStyles, cTextStyles, "the default text style for text objects", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"update on change", pUpdateOn, cBoolean, "Redraw after each change?", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		}, { }, 
	"drawing areas", cDrawingArea, isPlural,
	"graphic line", cGraphicLine, "A graphic line",
		{
		"start point", pStartPoint, cQDPoint, "the starting point of the line", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"end point", pEndPoint, cQDPoint, "the ending point of the line", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"dash style", pDashStyle, typeDashStyle, "the dash style", reserved, listOfItems, notEnumerated, readWrite, Reserved11, singular, 
		"arrow style", pLineArrow, enumArrows, "the arrow style", reserved, singleItem, enumerated, readWrite, Reserved11, singular
		}, { },
	"graphic lines", cGraphicLine, isPlural, 
	"graphic object", cGraphicObject, "A graphic object", { }, { },
	"graphic objects", cGraphicObject, isPlural, 
	"graphic shape", cGraphicShape, "A graphic shape", { }, { },
	"graphic shapes", cGraphicShape, isPlural, 
	"graphic text", cGraphicText, "A series of characters within a drawing area",
		{
		"color", pColor, cRGBColor, "the color of the first character", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"font", pFont, cText, "the name of the font of the first character", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"size", pPointSize, cFixed, "the size in points of the first character", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"uniform styles", pUniformStyles, cTextStyles, "the text styles that are uniform throughout the text", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		}, { },
	"graphic group", cGroupedGraphic, "Group of graphics", { }, { },
	"graphic groups", cGroupedGraphic, isPlural, 
	"oval", cOval, "An oval", { }, { },
	"ovals", cOval, isPlural, 
	"pixel", cPixel, "A pixel",
		{
		"color", pColor, cRGBColor, "the color", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		}, { },
	"pixels", cPixel, isPlural, 
	"pixel map", cPixelMap, "A pixel map", { }, { },
	"pixel maps", cPixelMap, isPlural, 
	"polygon", cPolygon, "A polygon",
		{
		"point list", pPointList, typeQDPoint, "the list of points that define the polygon", reserved, listOfItems, notEnumerated, readWrite, Reserved11, singular, 
		}, { },
	"polygons", cPolygon, isPlural, 
	"rectangle", cRectangle, "A rectangle", { }, { },
	"rectangles", cRectangle, isPlural, 
	"rounded rectangle", cRoundedRectangle, "A rounded rectangle",
		{
		"corner curve height", pCornerCurveHeight, cShortInteger, "the height of the oval used to define the shape of the rounded corners", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"corner curve width", pCornerCurveWidth, cShortInteger, "the width of the oval used to define the shape of the rounded corners", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		}, { },
	"rounded rectangles", cRoundedRectangle, isPlural, 
	},

	{ },

/* Enumerations */
	{
	enumTransferMode,
		{
		"copy pixels", kAEQDCopy, "", 
		"not copy pixels", kAEQDNotCopy, "", 
		"or pixels", kAEQDOr, "", 
		"not or pixels", kAEQDNotOr, "", 
		"bic pixels", kAEQDBic, "", 
		"not bic pixels", kAEQDNotBic, "", 
		"xor pixels", kAEQDXor, "", 
		"not xor pixels", kAEQDNotXor, "", 
		"add over pixels", kAEQDAddOver, "", 
		"add pin pixels", kAEQDAddPin, "", 
		"sub over pixels", kAEQDSubOver, "", 
		"sub pin pixels", kAEQDSubPin, "", 
		"ad max pixels", kAEQDAdMax, "", 
		"ad min pixels", kAEQDAdMin, "", 
		"blend pixels", kAEQDBlend, "", 
		}, 
	enumArrows,
		{
		"no arrow", kAENoArrow , "No arrow on line", 
		"arrow at start", kAEArrowAtStart , "Arrow at start of line", 
		"arrow at end", kAEArrowAtEnd , "Arrow at end of line", 
		"arrow at both ends", kAEArrowBothEnds , "Arrow at both the start and the end of the line",
		}
	},

/*

QuickDraw Graphics Supplemental Suite

*/

	"QuickDraw Graphics Supplemental Suite", "Defines transformations of graphic objects", kAEQDSupplementalSuite, 1, 1,

	{ },

/* Classes */
	{
	"drawing area", cDrawingArea, "Container for graphics and supporting information",
		{
		"rotation", pRotation, cRotation, "the default rotation for objects in the drawing area", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"scale", pScale, cFixed, "the default scaling for objects in the drawing area", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"translation", pTranslation, cQDPoint, "the default repositioning for objects in the drawing area", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		}, { },
	"drawing areas", cDrawingArea, isPlural, 
	"graphic group", cGroupedGraphic, "Group of graphics", { }, { },
	"graphic groups", cGroupedGraphic, isPlural, 
	}, 
	
	{ },

	{ },

/*

Table Suite 

*/
	"Table Suite", "Classes for manipulating tables", kAETableSuite, 1, 1,

	{ },

/* Classes */
	{
	"cell", cCell, "A cell",
		{
		"formula", pFormula, cText, "the formula of the cell", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		"protection", pProtection, enumProtection, "Indicates whether value or formula in the cell can be changed", reserved, singleItem, enumerated, readWrite, Reserved11, singular, 
		}, { },
	"cells", cCell, isPlural, 
	"column", cColumn, "A column",
		{
		"name", pName, cIntlText, "the name of the column", reserved, singleItem, notEnumerated, readWrite, Reserved11, singular, 
		}, { },
	"columns", cColumn, isPlural, 
	"row", cRow, "A row", { }, { },
	"rows", cRow, isPlural, 
	"table", cTable, "A table", { }, { },
	"tables", cTable, isPlural, 
	},
	
	{ },

/* Enumerations */
	{
	enumProtection,
		{
		"read only", kAENonmodifiable , "Cant change values or formulas", 
		"formulas protected", kAEFormulaProtect , "Can changes values but not formulas", 
		"read/write", kAEModifiable , "Can change values and formulas"
	}
}, 


/* 

Macintosh Connectivity Classes 

*/

	"Macintosh Connectivity Classes", "Classes relating to Apple Macintosh personal computer connectivity", kConnSuite, 1, 1,
		
	{ },

/* Classes */
	{
	"device specification", cDevSpec, "A device connected to a computer",
		{
		"properties", pProperties, cRecord, "property that allows getting and setting of multiple properties", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"device type", pDeviceType, eDeviceType, "the kind of device", reserved, singleItem, enumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"device address", pDeviceAddress, cAddressSpec, "the address of the device", reserved, singleItem, enumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
		}, { },
	"device specifications", cDevSpec, isPlural, 
	"address specification", cAddressSpec, "Unique designation of a device or service connected to this computer",
		{
		"properties", pProperties, cRecord, "property that allows getting and setting of multiple properties", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"conduit", pConduit, eConduit, "How the addressee is physically connected", reserved, singleItem, enumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"protocol", pProtocol, eProtocol, "How to talk to this addressee", reserved, singleItem, enumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular
		}, { },
	"address specifications", cAddressSpec, isPlural, 
	"ADB address", cADBAddress, "Addresses a device connected via Apple Desktop Bus",
		{
		"<inheritance>", pInherits, cAddressSpec, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"ID", pID, typeShortInteger, "the Apple Desktop Bus device ID", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular
		}, { },
	"ADB addresses", cADBAddress, isPlural, 
	"AppleTalk address", cAppleTalkAddress, "Addresses a device or service connected via the AppleTalk protocol",
		{
		"<inheritance>", pInherits, cAddressSpec, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"AppleTalk machine", pATMachine, typeChar, "the machine name part of the address", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"AppleTalk zone", pATZone, typeChar, "the zone part of the address", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"AppleTalk type", pATType, typeChar, "the type part of the AppleTalk address", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular
		}, { },
	"AppleTalk addresses", cAppleTalkAddress, isPlural, 
	"bus slot", cBusAddress, "Addresses a PC, PCI, or NuBus card",
		{
		"<inheritance>", pInherits, cAddressSpec, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"ID", pID, typeShortInteger, "the slot number", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular
		}, { },
	"bus slots", cBusAddress, isPlural, 
	"Ethernet address", cEthernetAddress, "Addresses a device by its Ethernet address",
		{
		"<inheritance>", pInherits, cAddressSpec, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"ID", pID, typeLongInteger, "the Ethernet address", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular
		}, { },
	"Ethernet addresses", cEthernetAddress, isPlural, 
	"FireWire address", cFireWireAddress, "Addresses a device on the FireWire bus",
		{
		"<inheritance>", pInherits, cAddressSpec, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"ID", pID, typeShortInteger, "the FireWire device ID", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular
		}, { },
	"FireWire addresses", cFireWireAddress, isPlural, 
	"IP address", cIPAddress, "Addresses a device or service via the Internet Protocol (IP)",
		{
		"<inheritance>", pInherits, cAddressSpec, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"ID", pID, typeChar, "the address in the form \"127.201.0.1\"", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"DNS form", pDNS, typeChar, "the address in the form \"apple.com\"", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"port", pPort, typeChar, "the port number of the service or client being addressed", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular
		}, { },
	"IP addresses", cIPAddress, isPlural, 
	"LocalTalk address", cLocalTalkAddress, "Addresses a device by its LocalTalk address",
		{
		"<inheritance>", pInherits, cAddressSpec, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"network", pNetwork, typeShortInteger, "the LocalTalk network number", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"node", pNode, typeShortInteger, "the LocalTalk node number", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"socket", pSocket, typeShortInteger, "the LocalTalk socket number", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular
		}, { },
	"LocalTalk addresses", cLocalTalkAddress, isPlural, 
	"SCSI address", cSCSIAddress, "Addresses a SCSI device",
		{
		"<inheritance>", pInherits, cAddressSpec, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"SCSI bus", pSCSIBus, typeShortInteger, "the SCSI bus number", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"ID", pID, typeShortInteger, "the SCSI ID", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"LUN", pSCSILUN, typeShortInteger, "the SCSI logical unit number", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular
		}, { },
	"SCSI addresses", cSCSIAddress, isPlural, 
	"Token Ring address", cTokenRingAddress, "Addresses a device or service via the Token Ring protocol",
		{
		"<inheritance>", pInherits, cAddressSpec, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"ID", pID, typeShortInteger, "the Token Ring ID", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular
		}, { },
	"Token Ring addresses", cTokenRingAddress, isPlural, 
	"USB address", cUSBAddress, "Addresses a device on the Universal Serial Bus",
		{
		"<inheritance>", pInherits, cAddressSpec, "inherits some of its properties from this class", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular, 
		"name", pName, typeChar, "the USB device name", reserved, singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular
		}, { },
	"USB Addresses", cUSBAddress, isPlural, 
	},
	
	{ },

/* Enumerations */
	{		
	eDeviceType,
		{
		"hard disk drive", 		eHD, "", 
		"floppy disk drive", 	eFloppy, "", 
		"CD ROM drive", 		eCDROM, "", 
		"DVD drive", 			eDVD, "",
		 "storage device", 		eStorageDevice, "", 
		 "keyboard", 			eKeyboard, "", 
		 "mouse", 				eMouse, "", 
		 "trackball", 			eTrackball, "", 
		 "trackpad", 			eTrackpad, "", 
		 "pointing device", 	ePointingDevice, "", 
		 "video monitor", 		eVideoMonitor, "", 
		 "LCD display", 		eLCD, "", 
		 "display", 			eDisplay, "", 
		 "modem", 				eModem, "", 
		 "PC card", 			ePCcard, "", 
		 "PCI card", 			ePCIcard, "", 
		 "NuBus card", 			eNuBuscard, "", 
		 "printer", 			ePrinter, "", 
		 "speakers", 			eSpeakers, "", 
		 "microphone", 			eMicrophone, ""
		}, 
	eConduit,
		{
		"ADB", 					eADB, "", 
		"printer port", 		ePrinterPort, "", 
		"modem port", 			eModemPort, "", 
		"modem printer port", 	eModemPrinterPort, "", 
		"LocalTalk", 			eLocalTalk, "", 
		"Ethernet", 			eEthernet, "", 
		"Token Ring",			eTokenRing, "", 
		"SCSI", 				eSCSI, "", 
		"USB", 					eUSB, "", 
		"FireWire", 			eFireWire, "", 
		"infrared", 			eInfrared, "", 
		"PC card", 				ePCcard, "", 
		"PCI bus", 				ePCIbus, "", 
		"NuBus", 				eNuBus, "", 
		"PDS slot", 			ePDSslot, "", 
		"Comm slot", 			eCommSlot, "", 
		"monitor out", 			eMonitorOut, "", 
		"video out", 			eVideoOut, "", 
		"video in", 			eVideoIn, "", 
		"audio out", 			eAudioOut, "", 
		"audio line in", 		eAudioLineIn, "", 
		"audio line out",		eAudioLineOut, "", 
		"microphone", 			eMicrophone, ""
		}, 
	eProtocol,
		{
		"serial", 				eSerial, "", 
		"AppleTalk", 			eAppleTalk, "", 
		"IP", 					eIP, "", 
		"SCSI", 				eSCSI, "", 
		"ADB", 					eADB, "", 
		"FireWire", 			eFireWire, "", 
		"IrDA", 				eIrDA, "", 
		"IRTalk",				eIRTalk, "", 
		"USB", 					eUSB, "", 
		"PC card", 				ePCcard, "", 
		"PCI bus", 				ePCIbus, "", 
		"NuBus",				eNuBus, "", 
		"bus", 					eBus, "", 
		"Macintosh video", 		eMacVideo, "", 
		"SVGA", 				eSVGA, "", 
		"S video", 				eSVideo, "", 
		"analog audio", 		eAnalogAudio, "", 
		"digital audio", 		eDigitalAudio, "", 
		"PostScript",			ePostScript, "", 
		}, 
	}, 

/*

Type Names Suite

*/
	"Type Names Suite", "Terminology for Registry data types", kASTypeNamesSuite, 1, 1,
		
	{ },

/* Classes */
	{
	"type class info", typeClassInfo, "information about properties and elements of a class", { }, { }, 
	"type event info", typeEventInfo, "information about an event", { }, { }, 
	"plain text", typeChar, isPlural, 
	"plain text", typeChar, "a synonym for string", { }, { },
	"string", typeChar, "a string of characters", { }, { }, 
	"bounding rectangle", cQDRectangle, "bounding rectangle", { }, { }, 
	"point", cQDPoint, "point coordinates", { }, { }, 
	"fixed", cFixed, "a real number", { }, { }, 
	"location reference", cInsertionLoc, "", { }, { }, 
	"application dictionary", typeAETE, "", { }, { }, 
	"color table", cColorTable, "", { }, { }, 
	"dash style", typeDashStyle, "", { }, { }, 
	"double integer", typeComp, "", { }, { }, 
	"extended real", typeExtended, "", { }, { },
	"fixed point", cFixedPoint, "", { }, { }, 
	"fixed rectangle", cFixedRectangle, "", { }, { }, 
	"long fixed", cLongFixed, "", { }, { }, 
	"long fixed point", cLongFixedPoint, "", { }, { }, 
	"long fixed rectangle", cLongFixedRectangle, "", { }, { }, 
	"long point", cLongPoint, "", { }, { }, 
	"long rectangle", cLongRectangle, "", { }, { }, 
	"machine location", typeMachineLoc, "", { }, { }, 
	"menu", cMenu, "", { }, { }, 
	"menu item", cMenuItem, "", { }, { }, 
	"null", typeNull, "", { }, { },
	"pixel map record", typePixMapMinus, "", { }, { }, 
	"PostScript picture", typeEPS, "", { }, { }, 
	"RGB16 color", typeRGB16, "", { }, { }, 
	"RGB96 color", typeRGB96, "", { }, { }, 
	"small integer", cShortInteger, "", { }, { }, 
	"small real", cSmallReal, "", { }, { }, 
	"system dictionary", typeAEUT, "", { }, { }, 
	"rotation", cRotation, "", { }, { }, 
	"scrap styles", typeScrapStyles, "", { }, { }, 
	"TIFF picture", typeTIFF, "", { }, { }, 
	"version", cVersion, "", { }, { }, 
	"unsigned integer", typeMagnitude, "", { }, { }, 
	"type property info", typePropInfo, "", { }, { }, 
	"type element info", typeElemInfo, "", { }, { }, 
	"type parameter info", typeParamInfo, "", { }, { }, 
	"type suite info", typeSuiteInfo, "", { }, { }, 
	"target id", typeTargetID, "", { }, { }, 
	}, 
	
	{ },

	{ },

	}
};
